@@ -50,7 +50,7 @@ except ImportError:
 from . import auth, config, ical, log, pathutils, rights, storage, xmlutils
 
 
-VERSION = "1.1"
+VERSION = "1.1.7"
 
 # Standard "not allowed" response that is returned when an authenticated user
 # tries to access information they don't have rights to
@@ -453,7 +453,7 @@ class Application(object):
     def do_HEAD(self, environ, read_collections, write_collections, content,
                 user):
         """Manage HEAD request."""
-        status, headers, answer = self.get(
+        status, headers, answer = self.do_GET(
             environ, read_collections, write_collections, content, user)
         return status, headers, None
 
